@@ -75,8 +75,6 @@ struct _PanelAppletPrivate {
         int                         size_hints_len;
 
 	gboolean                    moving_focus_out;
-	int                         focusable_child;
-	guint                       hierarchy_changed_id;
 
 	gboolean                    locked_down;
 };
@@ -420,25 +418,23 @@ panel_applet_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-static GtkWidget*
-panel_applet_container_has_focusable_child (GtkWidget *widget)
+static gboolean
+container_has_focusable_child (GtkContainer *container)
 {
-	GtkContainer *container;
 	GtkWidget *child;
 	GList *list;
 	GList *t;
-	GtkWidget *retval = NULL;
+	gboolean retval = FALSE;
 
-	container = GTK_CONTAINER (widget);
 	list = gtk_container_get_children (container);
 
 	for (t = list; t; t = t->next) {
 		child = GTK_WIDGET (t->data);
 		if (GTK_WIDGET_CAN_FOCUS (child)) {
-			retval = child;
+			retval = TRUE;
 			break;
 		} else if (GTK_IS_CONTAINER (child)) {
-			retval = panel_applet_container_has_focusable_child (child);
+			retval = container_has_focusable_child (GTK_CONTAINER (child));
 			if (retval)
 				break;
 		}
@@ -447,32 +443,6 @@ panel_applet_container_has_focusable_child (GtkWidget *widget)
 	return retval;	
 }
 
-static void
-panel_applet_hierarchy_changed_cb (GtkWidget *widget)
-{
-	PanelApplet *applet = PANEL_APPLET (widget);
-
-	applet->priv->focusable_child = -1;
-}
-
-static gboolean
-panel_applet_has_focusable_child (PanelApplet *applet)
-{
-	if (applet->priv->focusable_child == -1) {
-		GtkWidget *focusable_child;
-
-		if (!applet->priv->hierarchy_changed_id)
-			applet->priv->hierarchy_changed_id = 
-				g_signal_connect (applet, "hierarchy-changed", 
-				  		  G_CALLBACK (panel_applet_hierarchy_changed_cb),
-				  		  NULL);
-
-		focusable_child = panel_applet_container_has_focusable_child (GTK_WIDGET (applet));
-		applet->priv->focusable_child = (focusable_child != NULL);
-	}
-	return  (applet->priv->focusable_child != 0);
-}
-
 static void
 panel_applet_position_menu (GtkMenu   *menu,
 			    int       *x,
@@ -531,7 +501,7 @@ panel_applet_can_focus (GtkWidget *widget)
 	if (!PANEL_IS_APPLET (widget))
 		return FALSE;
 
-	return !panel_applet_has_focusable_child (PANEL_APPLET (widget));
+	return !container_has_focusable_child (GTK_CONTAINER (widget));
 }
 
 static gboolean
@@ -540,7 +510,7 @@ panel_applet_button_press (GtkWidget      *widget,
 {
 	PanelApplet *applet = PANEL_APPLET (widget);
 
-	if (!panel_applet_has_focusable_child (applet)) {
+	if (!container_has_focusable_child (GTK_CONTAINER (applet))) {
 		if (!GTK_WIDGET_HAS_FOCUS (widget)) {
 			GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
 			gtk_widget_grab_focus (widget);
@@ -1459,9 +1429,6 @@ panel_applet_setup (PanelApplet *applet)
 
 	g_signal_connect (applet, "popup_menu",
 			  G_CALLBACK (panel_applet_popup_menu), NULL);
-
-	priv->focusable_child = -1;
-	priv->hierarchy_changed_id  = 0;
 }
 
 GtkWidget *
